@@ -38,5 +38,21 @@ set.control.class <- function(myname=as.character(RDS::ult(sys.calls(),2)[[1L]])
   control
 }
 
-# Disable partial matching in control lists.
-`$.control.list` <- getElement
+#' Named element accessor for ergm control lists
+#' 
+#' Utility method that overrides the standard `$' list accessor to disable
+#' partial matching for ergm \code{control.list} objects
+#' 
+#' Executes \code{\link[base]{getElement}} instead of \code{\link[base]{$}} so
+#' that element names must match exactly to be returned and partially matching
+#' names will not return the wrong object.
+#' 
+#' @param object list-coearceable object with elements to be searched
+#' @param name literal character name of list element to search for and return
+#' @return Returns the named list element exactly matching \code{name}, or
+#' \code{NULL} if no matching elements found
+#' @author Pavel N. Krivitsky
+#' @seealso see \code{\link{getElement}}
+#' @name control.list.accessor
+#' @export
+`$.control.list` <- function(object, name) object[[name, exact = TRUE]]
